@@ -4,10 +4,9 @@
 
 #pragma once
 
-#include "Platforms/ImagePlatform.h"
+#include "Platforms/Platform.h"
 
 #include <QAbstractListModel>
-#include <QQmlEngine>
 
 /**
  * This is a model containing the current supported capture modes and their labels and shortcuts.
@@ -15,23 +14,9 @@
 class CaptureModeModel : public QAbstractListModel
 {
     Q_OBJECT
-    QML_ELEMENT
-    QML_SINGLETON
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged FINAL)
-
 public:
-    CaptureModeModel(QObject *parent = nullptr);
-
-    static CaptureModeModel *instance();
-
-    static CaptureModeModel *create(QQmlEngine *engine, QJSEngine *)
-    {
-        auto inst = instance();
-        Q_ASSERT(inst);
-        Q_ASSERT(inst->thread() == engine->thread());
-        QJSEngine::setObjectOwnership(inst, QJSEngine::CppOwnership);
-        return inst;
-    }
+    CaptureModeModel(Platform::GrabModes grabModes, QObject *parent = nullptr);
 
     enum CaptureMode {
         RectangularRegion,
@@ -40,8 +25,7 @@ public:
         AllScreensScaled,
         CurrentScreen,
         ActiveWindow,
-        WindowUnderCursor,
-        FullScreen,
+        WindowUnderCursor
     };
     Q_ENUM(CaptureMode)
 
@@ -56,9 +40,7 @@ public:
 
     int indexOfCaptureMode(CaptureMode captureMode) const;
 
-    void setGrabModes(ImagePlatform::GrabModes modes);
-
-    static QString captureModeLabel(CaptureMode mode);
+    void setGrabModes(Platform::GrabModes modes);
 
 Q_SIGNALS:
     void captureModesChanged();
@@ -68,10 +50,10 @@ private:
     struct Item {
         CaptureModeModel::CaptureMode captureMode;
         QString label;
-        QString shortcuts = {}; // default value in case there's nothing
+        QString shortcuts; // default value in case there's nothing
     };
 
-    QList<Item> m_data;
+    QVector<Item> m_data;
     QHash<int, QByteArray> m_roleNames;
-    ImagePlatform::GrabModes m_grabModes;
+    Platform::GrabModes m_grabModes;
 };
