@@ -7,33 +7,38 @@
 #ifndef EXPORTMENU_H
 #define EXPORTMENU_H
 
-#include <QMenu>
+#include "SpectacleMenu.h"
 
 #include "Config.h"
 #include "ExportManager.h"
 
 #ifdef PURPOSE_FOUND
 #include <Purpose/AlternativesModel>
+#include <purpose_version.h>
+#if PURPOSE_VERSION >= QT_VERSION_CHECK(5, 104, 0)
+#include <Purpose/Menu>
+#else
 #include <PurposeWidgets/Menu>
 #endif
+#endif
 
-class ExportMenu : public QMenu
+class ExportMenu : public SpectacleMenu
 {
     Q_OBJECT
 
 public:
     explicit ExportMenu(QWidget *parent = nullptr);
-    void imageUpdated();
 
-private Q_SLOTS:
-
-    void populateMenu();
+public Q_SLOTS:
+    void openPrintDialog();
 
 Q_SIGNALS:
-
     void imageShared(int error, const QString &message);
 
 private:
+    Q_SLOT void onImageChanged();
+    Q_SLOT void openScreenshotsFolder();
+
     void getKServiceItems();
 
 #ifdef PURPOSE_FOUND
@@ -43,8 +48,6 @@ private:
     bool mUpdatedImageAvailable;
     Purpose::Menu *mPurposeMenu = nullptr;
 #endif
-
-    ExportManager *const mExportManager;
 };
 
 #endif // EXPORTMENU_H
