@@ -24,9 +24,11 @@ GeneralOptionsPage::GeneralOptionsPage(QWidget *parent)
     m_ui->regionTitle->setLevel(2);
 
     //On Wayland  we can't programmatically raise and focus the window so we have to hide the option
-    if (KWindowSystem::isPlatformWayland() || qstrcmp(qgetenv("XDG_SESSION_TYPE").data(), "wayland") == 0) {
+    if (KWindowSystem::isPlatformWayland() || qstrcmp(qgetenv("XDG_SESSION_TYPE").constData(), "wayland") == 0) {
         m_ui->kcfg_printKeyActionRunning->removeItem(2);
     }
 }
 
 GeneralOptionsPage::~GeneralOptionsPage() = default;
+
+#include "moc_GeneralOptionsPage.cpp"
