@@ -11,10 +11,9 @@
 class RecordingModeModel : public QAbstractListModel
 {
     Q_OBJECT
-    QML_ELEMENT
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged FINAL)
 public:
-    explicit RecordingModeModel(QObject *parent = nullptr);
+    RecordingModeModel(VideoPlatform::RecordingModes modes, QObject *parent = nullptr);
 
     enum {
         RecordingModeRole = Qt::UserRole + 1,
@@ -24,13 +23,10 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    int indexOfRecordingMode(VideoPlatform::RecordingMode mode) const;
-
-    void setRecordingModes(VideoPlatform::RecordingModes modes);
-
-    static QString recordingModeLabel(VideoPlatform::RecordingMode mode);
+    Q_SCRIPTABLE void startRecording(int row, bool withPointer);
 
 Q_SIGNALS:
+    void captureModesChanged();
     void countChanged();
 
 private:
@@ -39,7 +35,7 @@ private:
         QString label;
     };
 
-    QList<Item> m_data;
+    QVector<Item> m_data;
     QHash<int, QByteArray> m_roleNames;
     const VideoPlatform::RecordingModes m_modes;
 };
